@@ -1,6 +1,5 @@
 __author__ = 'Stefen Shawn'
-__date__ = '2021/9/4'
-__version__ = 'v1.4.2'
 __license__ = 'MIT'
 __address__ = "www.github.com/StepfenShawn/Cantonese"
-__label__ = "Support While Stmt in VM"
\ No newline at end of file
+__label__ = "Support While Stmt in VM"
+name = "Cantonese"
\ No newline at end of file
