@@ -6,7 +6,6 @@
 # 施工中... 请戴好安全帽
 from enum import Enum, unique
 from collections import namedtuple
-import six
 
 import src.env
 
@@ -111,6 +110,9 @@ UNARY_OPERATORS = {
     'INVERT':   Arithmetic.invert,  # ~ a
 }
 
+class RUNTIME_TYPE():
+    BREAK = 0
+
 class CanBlock(object):
     def __init__(self, _type, handler, level) -> None:
         self.type = _type
